# Introduction
A docstring is a string literal that is used to document a Python module, function, class, or method. 
It is a best practice to include a docstring for every function and class you write in Python, as it helps others 
understand your code and its purpose. Here is how you can create a docstring in Python:
- After the summary, add an empty line, followed by a more detailed description of the function or class.

- Use descriptive language to explain the purpose of the function or class, and include information about the inputs, 
outputs, and any exceptions that may be raised.

- If the function or class has parameters, list them along with their data types and a brief description of their purpose.

- If the function or class returns a value, specify the data type of the returned value and any relevant details.

- End the docstring with another triple-quote (""").

Here's an example of a docstring for a simple Python function:
```
class Rectangle:
    """
    A class representing a rectangle.

    :param length: The length of the rectangle.
    :type length: float
    :param width: The width of the rectangle.
    :type width: float
    """

    def __init__(self, length: float, width: float) -> None:
        """
        Initialize a Rectangle object.

        :param length: The length of the rectangle.
        :type length: float
        :param width: The width of the rectangle.
        :type width: float
        """
        self.length = length
        self.width = width

    def area(self) -> float:
        """
        Calculate the area of the rectangle.

        :return: The area of the rectangle.
        :rtype: float
        """
        return self.length * self.width

    def perimeter(self) -> float:
        """
        Calculate the perimeter of the rectangle.

        :return: The perimeter of the rectangle.
        :rtype: float
        """
        return 2 * (self.length + self.width)
```

``` commandline
Note that the docstring is enclosed in triple-quotes, and it includes a one-line summary, a more detailed description, parameter descriptions, and a return value description.
```
